<?php

namespace Botble\Career\Providers;

use Botble\LanguageAdvanced\Supports\LanguageAdvancedManager;
use Botble\Shortcode\View\View;
use Illuminate\Routing\Events\RouteMatched;
use Botble\Base\Traits\LoadAndPublishDataTrait;
use Botble\Career\Models\Career;
use Botble\Career\Repositories\Caches\PostCacheDecorator;
use Botble\Career\Repositories\Eloquent\PostRepository;
use Botble\Career\Repositories\Interfaces\PostInterface;
use Illuminate\Support\Facades\Event;
use Illuminate\Support\ServiceProvider;
use Botble\Career\Models\Category;
use Botble\Career\Repositories\Caches\CategoryCacheDecorator;
use Botble\Career\Repositories\Eloquent\CategoryRepository;
use Botble\Career\Repositories\Interfaces\CategoryInterface;
use Botble\Career\Models\Tag;
use Botble\Career\Repositories\Caches\TagCacheDecorator;
use Botble\Career\Repositories\Eloquent\TagRepository;
use Botble\Career\Repositories\Interfaces\TagInterface;
use Language;
use Note;
use SeoHelper;
use SlugHelper;

/**
 * @since 02/07/2016 09:50 AM
 */
class CareerServiceProvider extends ServiceProvider
{
    use LoadAndPublishDataTrait;

    public function register()
    {
        $this->app->bind(PostInterface::class, function () {
            return new PostCacheDecorator(new PostRepository(new Career));
        });

        $this->app->bind(CategoryInterface::class, function () {
            return new CategoryCacheDecorator(new CategoryRepository(new Category));
        });

       $this->app->bind(TagInterface::class, function () {
            return new TagCacheDecorator(new TagRepository(new Tag));
        });
    }

    public function boot()
    {
        SlugHelper::registerModule(Career::class, 'Blog Posts');
        SlugHelper::registerModule(Category::class, 'Blog Categories');
        SlugHelper::registerModule(Tag::class, 'Blog Tags');

        SlugHelper::setPrefix(Tag::class, 'tag', true);
        SlugHelper::setPrefix(Career::class, null, true);
        SlugHelper::setPrefix(Category::class, null, true);

        $this->setNamespace('plugins/career')
            ->loadHelpers()
            ->loadAndPublishConfigurations(['permissions', 'general'])
            ->loadAndPublishViews()
            ->loadAndPublishTranslations()
            ->loadRoutes(['web', 'api'])
            ->loadMigrations()
            ->publishAssets();

         $this->app->register(EventServiceProvider::class);

        Event::listen(RouteMatched::class, function () {
            dashboard_menu()
                ->registerItem([
                    'id'          => 'cms-plugins-career',
                    'priority'    => 3,
                    'parent_id'   => null,
                    'name'        => 'plugins/career::base.menu_name',
                    'icon'        => 'fa fa-edit',
                    //'url'         => route('posts.index'),
                    'url'         => url('admin/career/posts'),
                    'permissions' => ['posts.index'],
                ])
                ->registerItem([
                    'id'          => 'cms-plugins-career-post',
                    'priority'    => 1,
                    'parent_id'   => 'cms-plugins-career',
                    'name'        => 'plugins/career::posts.menu_name',
                    'icon'        => null,
                    //'url'         => route('posts.index'),
                    'url'         => url('admin/career/posts'),
                    'permissions' => ['posts.index'],
                ]);
               /* ->registerItem([
                    'id'          => 'cms-plugins-demo-categories',
                    'priority'    => 2,
                    'parent_id'   => 'cms-plugins-demo',
                    'name'        => 'plugins/demo::categories.menu_name',
                    'icon'        => null,
                    'url'         => route('categories.index'),
                    'permissions' => ['categories.index'],
                ]);
                ->registerItem([
                    'id'          => 'cms-plugins-demo-tags',
                    'priority'    => 3,
                    'parent_id'   => 'cms-plugins-demo',
                    'name'        => 'plugins/demo::tags.menu_name',
                    'icon'        => null,
                    'url'         => route('tags.index'),
                    'permissions' => ['tags.index'],
                ]);*/
        });

        $useLanguageV2 = $this->app['config']->get('plugins.career.general.use_language_v2', false) &&
            defined('LANGUAGE_ADVANCED_MODULE_SCREEN_NAME');

        if (defined('LANGUAGE_MODULE_SCREEN_NAME') && $useLanguageV2) {
            LanguageAdvancedManager::registerModule(Post::class, [
                'name',
                'description',
                'content',
            ]);

            LanguageAdvancedManager::registerModule(Category::class, [
                'name',
                'description',
            ]);

            LanguageAdvancedManager::registerModule(Tag::class, [
                'name',
                'description',
            ]);
        }

        $this->app->booted(function () use ($useLanguageV2) {
            $models = [Post::class, Category::class, Tag::class];

            if (defined('LANGUAGE_MODULE_SCREEN_NAME') && !$useLanguageV2) {
                Language::registerModule($models);
            }

            SeoHelper::registerModule($models);

            $configKey = 'packages.revision.general.supported';
            config()->set($configKey, array_merge(config($configKey, []), [Post::class]));

            if (defined('NOTE_FILTER_MODEL_USING_NOTE')) {
                Note::registerModule(Post::class);
            }

            $this->app->register(HookServiceProvider::class);
        });

        if (function_exists('shortcode')) {
            view()->composer([
                'plugins/career::themes.post',
                'plugins/career::themes.category',
                'plugins/career::themes.tag',
            ], function (View $view) {
                $view->withShortcodes();
            });
        }
    }
}
