<?php

namespace Botble\Author\Http\Controllers;

use Auth;
use Botble\Author\Models\Author;
use Botble\Author\Repositories\Interfaces\AuthorInterface;
use Botble\Base\Enums\BaseStatusEnum;
use Botble\Blog\Repositories\Interfaces\PostInterface;
use Botble\SeoHelper\SeoOpenGraph;
use Botble\Theme\Http\Controllers\PublicController as BaseController;
use Illuminate\Http\Response;
use Illuminate\Support\Arr;
use RvMedia;
use SeoHelper;
use SlugHelper;
use Theme;

class PublicController extends BaseController
{
    /**
     * @param string $slug
     * @param AuthorInterface $authorRepository
     * @return \Botble\Theme\Facades\Response|Response|\Response
     */
    public function getAuthor($slug, AuthorInterface $authorRepository)
    {
        $slug = SlugHelper::getSlug($slug, SlugHelper::getPrefix(Author::class), Author::class);

        if (!$slug) {
            abort(404);
        }

        $condition = [
            'id'     => $slug->reference_id,
            'status' => BaseStatusEnum::PUBLISHED,
        ];

        if (Auth::check() && request('preview')) {
            Arr::forget($condition, 'status');
        }

        $author = $authorRepository->getModel()
            ->where($condition)
            ->with(['slugable'])
            ->first();

        if (!$author) {
            abort(404);
        }

        SeoHelper::setTitle($author->getFullName())->setDescription($author->description);

        $meta = new SeoOpenGraph;
        if ($author->avatar) {
            $meta->setImage(RvMedia::getImageUrl($author->avatar));
        }
        $meta->setDescription($author->description);
        $meta->setUrl($author->url);
        $meta->setTitle($author->getFullName());
        $meta->setType('article');

        SeoHelper::setSeoOpenGraph($meta);

        Theme::breadcrumb()->add(__('Home'), url('/'))->add($author->getFullName(), $author->url);

        do_action(BASE_ACTION_PUBLIC_RENDER_SINGLE, AUTHOR_MODULE_SCREEN_NAME, $author);

        $posts = app(PostInterface::class)->advancedGet([
            'condition' => [
                'posts.status' => BaseStatusEnum::PUBLISHED,
                'author_id'    => $author->id,
                'author_type'  => Author::class,
            ],
            'paginate'  => [
                'per_page'      => 12,
                'current_paged' => (int) request()->input('page', 1),
            ],
            'order_by'  => ['created_at' => 'DESC'],
        ]);

        return Theme::scope('author', compact('author', 'posts'), 'plugins/author::themes.author')->render();
    }
}
