<?php

namespace Botble\Author\Listeners;

use Botble\Author\Repositories\Interfaces\AuthorInterface;
use Botble\Base\Enums\BaseStatusEnum;
use SiteMapManager;

class RenderingSiteMapListener
{
    /**
     * @var AuthorInterface
     */
    protected $authorRepository;

    /**
     * RenderingSiteMapListener constructor.
     * @param AuthorInterface $authorRepository
     */
    public function __construct(AuthorInterface $authorRepository)
    {
        $this->authorRepository = $authorRepository;
    }

    /**
     * Handle the event.
     *
     * @return void
     */
    public function handle()
    {
        $authors = $this->authorRepository->getModel()
            ->where('authors.status', BaseStatusEnum::PUBLISHED)
            ->orderBy('authors.created_at', 'desc')
            ->with(['slugable'])
            ->get();

        foreach ($authors as $author) {
            SiteMapManager::add($author->url, $author->updated_at, '0.8', 'daily');
        }
    }
}
