<?php

namespace Botble\Author\Models;

use Botble\Base\Enums\BaseStatusEnum;
use Botble\Base\Models\BaseModel;
use Botble\Base\Traits\EnumCastable;
use Botble\Blog\Models\Post;
use RvMedia;

class Author extends BaseModel
{
    use EnumCastable;

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'authors';

    /**
     * @var array
     */
    protected $fillable = [
        'name',
        'email',
        'description',
        'avatar',
        'status',
    ];

    /**
     * @var array
     */
    protected $casts = [
        'status' => BaseStatusEnum::class,
    ];

    /**
     * Always capitalize the first name when we retrieve it
     * @param string $value
     * @return string
     */
    public function getFirstNameAttribute($value)
    {
        return ucfirst($this->splitName($this->name)[0]);
    }

    /**
     * Always capitalize the last name when we retrieve it
     * @param string $value
     * @return string
     */
    public function getLastNameAttribute($value)
    {
        return ucfirst($this->splitName($this->name)[1]);
    }

    /**
     * @return string
     */
    public function getAvatarUrlAttribute()
    {
        return RvMedia::getImageUrl($this->avatar, 'thumb', false, RvMedia::getDefaultImage());
    }

    /**
     * @return string
     */
    public function getFullName()
    {
        return ucfirst($this->name);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\MorphMany
     */
    public function posts()
    {
        return $this->morphMany(Post::class, 'author');
    }

    /**
     * @param string $name
     * @return array
     */
    protected function splitName($name): array
    {
        $name = trim($name);

        $lastName = (strpos($name, ' ') === false) ? '' : preg_replace('#.*\s([\w-]*)$#', '$1', $name);

        $firstName = trim(preg_replace('#' . preg_quote($lastName, '#') . '#', '', $name));

        return [$firstName, $lastName];
    }
}
