<?php

namespace Botble\Blog\Repositories\Eloquent;

use Botble\Base\Enums\BaseStatusEnum;
use Botble\Blog\Repositories\Interfaces\CategoryInterface;
use Botble\Support\Repositories\Eloquent\RepositoriesAbstract;
use Eloquent;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Pagination\Paginator;
class CategoryRepository extends RepositoriesAbstract implements CategoryInterface
{

    /**
     * {@inheritDoc}
     */
    public function getDataSiteMap()
    {
        $data = $this->model
            ->with('slugable')
            ->where('status', BaseStatusEnum::PUBLISHED)
            ->orderBy('created_at', 'desc');

        return $this->applyBeforeExecuteQuery($data)->get();
    }

    /**
     * {@inheritDoc}
     */
    public function getFeaturedCategories($limit, array $with = [])
    {
        $data = $this->model
            ->with(array_merge(['slugable'], $with))
            ->where([
                'status'      => BaseStatusEnum::PUBLISHED,
                'is_featured' => 1,
            ])
            ->select([
                'id',
                'name',
                'description',
                'icon',
            ])
            ->orderBy('order')
            ->limit($limit);

        return $this->applyBeforeExecuteQuery($data)->get();
    }

    /**
     * {@inheritDoc}
     */
    public function getAllCategories(array $condition = [], array $with = [])
    {
        $data = $this->model->with('slugable');
        if (!empty($condition)) {
            $data = $data->where($condition);
        }

        $data = $data
            ->where('status', BaseStatusEnum::PUBLISHED)
            ->orderBy('order', 'DESC')
            ->orderBy('created_at', 'DESC');

        if ($with) {
            $data = $data->with($with);
        }

        return $this->applyBeforeExecuteQuery($data)->get();
    }

    /**
     * {@inheritDoc}
     */
    public function getCategoryById($id)
    {
        $data = $this->model->with('slugable')->where([
            'id'     => $id,
            'status' => BaseStatusEnum::PUBLISHED,
        ]);

        return $this->applyBeforeExecuteQuery($data, true)->first();
    }

    /**
     * {@inheritDoc}
     */
    public function getCategories(array $select, array $orderBy)
    {
        $data = $this->model
            ->where('status', BaseStatusEnum::PUBLISHED)
            ->with('slugable')
            ->select($select);

        foreach ($orderBy as $by => $direction) {
            $data = $data->orderBy($by, $direction);
        }

        return $this->applyBeforeExecuteQuery($data)->get();
    }

    /**
     * {@inheritDoc}
     */
    public function getAllRelatedChildrenIds($id)
    {
        if ($id instanceof Eloquent) {
            $model = $id;
        } else {
            $model = $this->getFirstBy(['id' => $id]);
        }

        if (!$model) {
            return null;
        }

        $result = [];

        $children = $model->children()->select('id')->get();

        foreach ($children as $child) {
            $result[] = $child->id;
            $result = array_merge($this->getAllRelatedChildrenIds($child), $result);
        }

        $this->resetModel();

        return array_unique($result);
    }

    /**
     * {@inheritDoc}
     */
    public function getAllCategoriesWithChildren(array $condition = [], array $with = [], array $select = ['*'])
    {
        $data = $this->model
            ->where($condition)
            ->with($with)
            ->select($select);

        return $this->applyBeforeExecuteQuery($data)->get();
    }

    /**
     * {@inheritDoc}
     */
    public function getFilters($filters)
    {
        $this->model = $this->originalModel;

        $orderBy = isset($filters['order_by']) ? $filters['order_by'] : 'created_at';

        $order = isset($filters['order']) ? $filters['order'] : 'desc';

        $this->model = $this->model->where('status', BaseStatusEnum::PUBLISHED)->orderBy($orderBy, $order);

        return $this->applyBeforeExecuteQuery($this->model)->paginate((int)$filters['per_page']);
    }

    /**
     * {@inheritDoc}
     */
    public function getPopularCategories(int $limit, array $with = ['slugable'], array $withCount = ['posts'])
    {
        $data = $this->model
            ->with($with)
            ->withCount($withCount)
            ->orderBy('posts_count', 'desc')
            ->where('status', BaseStatusEnum::PUBLISHED)
            ->limit($limit);

        return $this->applyBeforeExecuteQuery($data)->get();
    }
    public function getChildCategory($categoryId,$perPage=0,$limit = 0)
    {        

        if($limit==0){
            $limit=1000;
        } 
        if($perPage==0){
            $limit=12;$perPage=12;
        }                    
        $data2 = $this->model
            ->where('categories.status', BaseStatusEnum::PUBLISHED)           
            ->whereIn('categories.parent_id', array_filter((array)$categoryId))            
            ->select('categories.*')
            ->distinct()
            ->limit($limit)   
            ->with('slugable')
            ->orderBy('categories.created_at', 'desc')->get();
            //dd($data2); 
        
        $totalGroup = count($data2);
        
        if($categoryId[0] !=37 && $categoryId[0] ==33){
            $page = Paginator::resolveCurrentPage('page');
            $data2 = new LengthAwarePaginator($data2->forPage($page, $perPage), $totalGroup, $perPage, $page, [
                'path' => Paginator::resolveCurrentPath(),
                'pageName' => 'page',
            ]);    
        }
        return $data2;
        //$this->applyBeforeExecuteQuery($data)->limit($limit)->get();
    }

    public function getCategoryDetails($categoryId)
    {        
        // if (!is_array($categoryId)) {
        //     $categoryId = [$categoryId]; echo "gggg";print_r($categoryId);
        // }
       //echo "gggg";print_r($categoryId);
        //$categoryIdstr = implode(',',$categoryId);print_r($categoryIdstr);
        $data2 = $this->model
            ->where('categories.status', BaseStatusEnum::PUBLISHED)           
            ->where('categories.id', $categoryId)            
            ->select('categories.*')            
            ->with('slugable')->get();
            //dd($data2); 
        

        return $data2;//$this->applyBeforeExecuteQuery($data)->limit($limit)->get();
    }
    
}
