<?php

namespace Botble\Career\Models;

use Botble\ACL\Models\User;
use Botble\Base\Traits\EnumCastable;
use Botble\Base\Enums\BaseStatusEnum;
use Botble\Revision\RevisionableTrait;
use Botble\Base\Models\BaseModel;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\MorphTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use Botble\Career\Models\CareersJobs;

class Career extends BaseModel
{
    use RevisionableTrait;
    use EnumCastable;
    use SoftDeletes;

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'careers';

    /**
     * @var mixed
     */
    protected $revisionEnabled = true;

    /**
     * @var mixed
     */
    protected $revisionCleanup = true;

    /**
     * @var int
     */
    protected $historyLimit = 20;

    /**
     * @var array
     */
    protected $dontKeepRevisionOf = [
        'content',
        'views',
    ];

    /**
     * The date fields for the model.clear
     *
     * @var array
     */
    protected $dates = [
        'created_at',
        'updated_at',
    ];

    protected $fillable = ['job_id','f_name', 'email', 'phone', 'message', 'resume'];

    /**
     * @var array
     */
    protected $casts = [
        'status' => BaseStatusEnum::class,
    ];

    public function CareersJobs() : BelongsTo
    {
        return $this->belongsTo('Botble\Career\Models\CareersJobs','job_id','id')->withDefault();
    }


    /**
     * @return Category
     */
    public function getFirstCategoryAttribute()
    {
        return $this->categories->first();
    }


    /**
     * @return MorphTo
     */
    public function author(): MorphTo
    {
        return $this->morphTo()->withDefault();
    }

    protected static function boot()
    {
        parent::boot();

        static::deleting(function (Career $post) {
            $post->categories()->detach();
            $post->tags()->detach();
        });
    }
}
