<?php

namespace Botble\Demo\Providers;

use Botble\LanguageAdvanced\Supports\LanguageAdvancedManager;
use Botble\Shortcode\View\View;
use Illuminate\Routing\Events\RouteMatched;
use Botble\Base\Traits\LoadAndPublishDataTrait;
use Botble\Demo\Models\Testimonial;
use Botble\Demo\Repositories\Caches\PostCacheDecorator;
use Botble\Demo\Repositories\Eloquent\PostRepository;
use Botble\Demo\Repositories\Interfaces\PostInterface;
use Illuminate\Support\Facades\Event;
use Illuminate\Support\ServiceProvider;
use Language;
use Note;
use SeoHelper;
use SlugHelper;

/**
 * @since 02/07/2016 09:50 AM
 */
class DemoServiceProvider extends ServiceProvider
{
    public function register()
{
    if (setting('enable_cache', false)) { // Check if cache is enabled or disabled.
        // Binding repositories if cache is enabled.
        $this->app->singleton(PostInterface::class, function () {
            return new PostCacheDecorator(new PostRepository(new Demo()), new Cache($this->app['cache'], PostRepository::class));
        });
    } else {
        // Binding repositories if cache is disabled.
        $this->app->singleton(PostInterface::class, function () {
            return new PostRepository(new Demo());
        });
    }

    //Helper::autoload(__DIR__ . '/../../helpers'); // Load all constants/helpers from helpers folder.
}
    public function boot()
{
    $this->loadRoutesFrom(__DIR__.'/../../routes/web.php');
    Event::listen(RouteMatched::class, function () {
        dashboard_menu()
            ->registerItem([
                'id'          => 'cms-plugins-demo-post',
                'priority'    => 1,
                //'parent_id'   => 'cms-plugins-demo',
                'name'        => 'Testimonial',
                'icon'        => null,
                'url'         => route('posts.index'),
                //'permissions' => ['demo.list'],
            ]);
    });
    // Register plugin menu to admin menu
    Event::listen(SessionStarted::class, function () {
        dashboard_menu()->registerItem([
            'id' => 'cms-plugins-demo', // Id of menu. It must be unique
            'priority' => 5, // Position of plugin
            'parent_id' => null, // Parent ID, if it's not null, this menu will be submenu
            'name' => trans('plugins.demo::demo.name'),
            'icon' => 'fa fa-list',
            'url' => route('demo.list'),
            'permissions' => ['demo.list'], // Permission key, it's defined in /config/permisisons.php
        ]);
    });
}




}
